@@ -320,11 +320,18 @@ patt.worth<-function(fitobj, obj.names=NULL, outmat="worth"){
      if(ncol(worthmat)==1)   colnames(worthmat) <- "worth"
 
      switch(outmat,
-        "lambda" = return(estmat),
-        "worth" = return(worthmat),
+         "lambda" = {class(estmat)<-c("wmat",class(estmat));return(estmat)},
+         "worth" = {class(worthmat)<-c("wmat",class(worthmat));return(worthmat)},
+        # "est" = return(lambda.mat),
         stop("     outmat must be either 'worth' or 'lambda'\n")
      )
 
+#     switch(outmat,
+#        "lambda" = return(estmat),
+#        "worth" = return(worthmat),
+#        stop("     outmat must be either 'worth' or 'lambda'\n")
+#     )
+
   ## end pattdesignmodel
 
   } else {
